@@ -6,6 +6,7 @@
 #include "kdesktopfiletest.h"
 #include "helper.h"
 #include <kconfiggroup.h>
+#include <kdesktopfileaction.h>
 #include <ksharedconfig.h>
 #include <qtemporaryfile.h>
 
@@ -13,13 +14,17 @@
 
 #include <QTest>
 
+#if defined(Q_OS_UNIX)
+#include <unistd.h>
+#endif
+
 QTEST_MAIN(KDesktopFileTest)
 
 void KDesktopFileTest::initTestCase()
 {
     QStandardPaths::setTestModeEnabled(true);
 
-    KConfigGroup actionRestrictions(KSharedConfig::openConfig(), "KDE Action Restrictions");
+    KConfigGroup actionRestrictions(KSharedConfig::openConfig(), QStringLiteral("KDE Action Restrictions"));
     actionRestrictions.writeEntry("someBlockedAction", false);
 }
 
@@ -48,25 +53,6 @@ void KDesktopFileTest::testRead()
     QCOMPARE(df.fileName(), QFileInfo(fileName).canonicalFilePath());
 }
 
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-void KDesktopFileTest::testReadDirectory()
-{
-    QTemporaryFile file(QStringLiteral("testReadDirectoryXXXXXX.directory"));
-    QVERIFY(file.open());
-    const QString fileName = file.fileName();
-    QTextStream ts(&file);
-    ts << "[Desktop Entry]\n"
-          "Type=Directory\n"
-          "SortOrder=2.desktop;1.desktop;\n"
-          "\n";
-    file.close();
-    QVERIFY(QFile::exists(fileName));
-    KDesktopFile df(fileName);
-    QCOMPARE(df.readType(), QString::fromLatin1("Directory"));
-    QCOMPARE(df.sortOrder(), QStringList() << QString::fromLatin1("2.desktop") << QString::fromLatin1("1.desktop"));
-}
-#endif
-
 void KDesktopFileTest::testReadLocalized_data()
 {
     QTest::addColumn<QLocale>("locale");
@@ -175,15 +161,19 @@ void KDesktopFileTest::testActionGroup()
     QCOMPARE(df.hasActionGroup(QStringLiteral("semi;colon")), true);
     QCOMPARE(df.hasActionGroup(QStringLiteral("decrypt")), true);
     QCOMPARE(df.hasActionGroup(QStringLiteral("doesnotexist")), false);
-    KConfigGroup cg = df.actionGroup(QStringLiteral("encrypt"));
-    QVERIFY(cg.hasKey("Name"));
-    QCOMPARE(cg.readEntry("Name"), QStringLiteral("Encrypt file"));
-    cg = df.actionGroup(QStringLiteral("decrypt"));
-    QVERIFY(cg.hasKey("Name"));
-    QCOMPARE(cg.readEntry("Name"), QStringLiteral("Decrypt file"));
-    cg = df.actionGroup(QStringLiteral("semi;colon"));
-    QVERIFY(cg.hasKey("Name"));
-    QCOMPARE(cg.readEntry("Name"), QStringLiteral("With semicolon"));
+
+    const auto actions = df.actions();
+    QCOMPARE(actions.size(), 3);
+    QVERIFY(std::all_of(actions.begin(), actions.end(), [&fileName](const KDesktopFileAction &action) {
+        return action.desktopFilePath() == fileName;
+    }));
+    QCOMPARE(actions.at(0).actionsKey(), QStringLiteral("encrypt"));
+    QCOMPARE(actions.at(0).name(), QStringLiteral("Encrypt file"));
+    QCOMPARE(actions.at(1).actionsKey(), QStringLiteral("semi;colon"));
+    QCOMPARE(actions.at(1).name(), QStringLiteral("With semicolon"));
+    QCOMPARE(actions.at(2).name(), QStringLiteral("Decrypt file"));
+    QCOMPARE(actions.at(2).actionsKey(), QStringLiteral("decrypt"));
+    QCOMPARE(actions.at(2).name(), QStringLiteral("Decrypt file"));
 }
 
 void KDesktopFileTest::testIsAuthorizedDesktopFile()
@@ -199,14 +189,25 @@ void KDesktopFileTest::testIsAuthorizedDesktopFile()
           "\n";
     file.close();
     QVERIFY(QFile::exists(fileName));
-    QVERIFY(!KDesktopFile::isAuthorizedDesktopFile(fileName));
 
-    const QString installedFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("/kservices5/http_cache_cleaner.desktop"));
-    if (!installedFile.isEmpty()) {
-        QVERIFY(KDesktopFile::isAuthorizedDesktopFile(installedFile));
-    } else {
-        qWarning("Skipping test for http_cache_cleaner.desktop, not found. kio not installed?");
+#if defined(Q_OS_UNIX)
+    // Try to fix test failing in docker running as root
+    const QFileInfo entryInfo(fileName);
+    if (entryInfo.ownerId() == 0) {
+        // try to find a valid user/group combination
+        for (int i = 1; i < 100; ++i) {
+            if (chown(fileName.toLocal8Bit().constData(), i, i) == 0) {
+                break;
+            }
+        }
+        const QFileInfo entryInfo1(fileName);
+        if (entryInfo1.ownerId() == 0) {
+            QEXPECT_FAIL("", "Running test as root and could not find a non root user to change the ownership of the file too", Continue);
+        }
     }
+#endif
+
+    QVERIFY(!KDesktopFile::isAuthorizedDesktopFile(fileName));
 
     const QString autostartFile = QStandardPaths::locate(QStandardPaths::GenericConfigLocation, QStringLiteral("autostart/plasma-desktop.desktop"));
     if (!autostartFile.isEmpty()) {
@@ -297,3 +298,5 @@ void KDesktopFileTest::testLocateLocal()
 
     QCOMPARE(KDesktopFile::locateLocal(path), result);
 }
+
+#include "moc_kdesktopfiletest.cpp"
