@@ -22,7 +22,6 @@
 #include <QVariant>
 
 class KConfigGroup;
-class KEntryMap;
 class KConfigPrivate;
 
 /**
@@ -36,12 +35,12 @@ class KConfigPrivate;
  *
  * Load a specific configuration file:
  * \code
- * KConfig config( "/etc/kderc", KConfig::SimpleConfig );
+ * KConfig config("/etc/kderc", KConfig::SimpleConfig);
  * \endcode
  *
  * Load the configuration of a specific component:
  * \code
- * KConfig config( "pluginrc" );
+ * KConfig config("pluginrc");
  * \endcode
  *
  * In general it is recommended to use KSharedConfig instead of
@@ -317,33 +316,6 @@ public:
     bool isImmutable() const override;
     /// @}
 
-    /// @{ global
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(4, 0)
-    /**
-     * Forces all following write-operations to be performed on @c kdeglobals,
-     * independent of the @c Global flag in writeEntry().
-     *
-     * @param force true to force writing to kdeglobals
-     * @see forceGlobal
-     * @deprecated Since 4.0
-     */
-    KCONFIGCORE_DEPRECATED_VERSION(4, 0, "Not recommended")
-    void setForceGlobal(bool force);
-#endif
-
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(4, 0)
-    /**
-     * Returns whether all entries are being written to @c kdeglobals.
-     *
-     * @return @c true if all entries are being written to @c kdeglobals
-     * @see setForceGlobal
-     * @deprecated Since 4.0
-     */
-    KCONFIGCORE_DEPRECATED_VERSION(4, 0, "Not recommended")
-    bool forceGlobal() const;
-#endif
-    /// @}
-
     /// @reimp
     QStringList groupList() const override;
 
@@ -373,11 +345,11 @@ public:
     static QString mainConfigName();
 
 protected:
-    bool hasGroupImpl(const QByteArray &group) const override;
-    KConfigGroup groupImpl(const QByteArray &b) override;
-    const KConfigGroup groupImpl(const QByteArray &b) const override;
-    void deleteGroupImpl(const QByteArray &group, WriteConfigFlags flags = Normal) override;
-    bool isGroupImmutableImpl(const QByteArray &aGroup) const override;
+    bool hasGroupImpl(const QString &groupName) const override;
+    KConfigGroup groupImpl(const QString &groupName) override;
+    const KConfigGroup groupImpl(const QString &groupName) const override;
+    void deleteGroupImpl(const QString &groupName, WriteConfigFlags flags = Normal) override;
+    bool isGroupImmutableImpl(const QString &groupName) const override;
 
     friend class KConfigGroup;
     friend class KConfigGroupPrivate;
@@ -390,13 +362,11 @@ protected:
 
     KConfigPrivate *const d_ptr;
 
-    KConfig(KConfigPrivate &d);
+    KCONFIGCORE_NO_EXPORT explicit KConfig(KConfigPrivate &d);
 
 private:
     friend class KConfigTest;
 
-    QStringList keyList(const QString &aGroup = QString()) const;
-
     Q_DISABLE_COPY(KConfig)
 
     Q_DECLARE_PRIVATE(KConfig)
