@@ -51,12 +51,12 @@ struct KStandardShortcutInfo {
     Category category;
 };
 
-#define CTRL(x) Qt::CTRL | Qt::Key_##x
-#define SHIFT(x) Qt::SHIFT | Qt::Key_##x
-#define CTRLALT(x) Qt::CTRL | Qt::ALT | Qt::Key_##x
-#define CTRLSHIFT(x) Qt::CTRL | Qt::SHIFT | Qt::Key_##x
-#define ALT(x) Qt::ALT | Qt::Key_##x
-#define ALTSHIFT(x) Qt::ALT | Qt::SHIFT | Qt::Key_##x
+#define CTRL(x) QKeyCombination(Qt::CTRL | Qt::Key_##x).toCombined()
+#define SHIFT(x) QKeyCombination(Qt::SHIFT | Qt::Key_##x).toCombined()
+#define CTRLALT(x) QKeyCombination(Qt::CTRL | Qt::ALT | Qt::Key_##x).toCombined()
+#define CTRLSHIFT(x) QKeyCombination(Qt::CTRL | Qt::SHIFT | Qt::Key_##x).toCombined()
+#define ALT(x) QKeyCombination(Qt::ALT | Qt::Key_##x).toCombined()
+#define ALTSHIFT(x) QKeyCombination(Qt::ALT | Qt::SHIFT | Qt::Key_##x).toCombined()
 
 /** Array of predefined KStandardShortcutInfo objects, which cover all
     the "standard" accelerators. Each enum value from StandardShortcut
@@ -294,7 +294,14 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {PrintPreview, "PrintPreview", QT_TRANSLATE_NOOP3("KStandardShortcut", "Print Preview", "@action"), 0, 0, QList<QKeySequence>(), false, Category::File},
     {Mail, "Mail", QT_TRANSLATE_NOOP3("KStandardShortcut", "Mail", "@action"), 0, 0, QList<QKeySequence>(), false, Category::Help},
     {Clear, "Clear", QT_TRANSLATE_NOOP3("KStandardShortcut", "Clear", "@action"), 0, 0, QList<QKeySequence>(), false, Category::Edit},
-    {ActualSize, "ActualSize", QT_TRANSLATE_NOOP3("KStandardShortcut", "Zoom to Actual Size", "@action"), CTRL(0), 0, QList<QKeySequence>(), false, Category::View},
+    {ActualSize,
+     "ActualSize",
+     QT_TRANSLATE_NOOP3("KStandardShortcut", "Zoom to Actual Size", "@action"),
+     CTRL(0),
+     0,
+     QList<QKeySequence>(),
+     false,
+     Category::View},
     {FitToPage, "FitToPage", QT_TRANSLATE_NOOP3("KStandardShortcut", "Fit To Page", "@action"), 0, 0, QList<QKeySequence>(), false, Category::View},
     {FitToWidth, "FitToWidth", QT_TRANSLATE_NOOP3("KStandardShortcut", "Fit To Width", "@action"), 0, 0, QList<QKeySequence>(), false, Category::View},
     {FitToHeight, "FitToHeight", QT_TRANSLATE_NOOP3("KStandardShortcut", "Fit To Height", "@action"), 0, 0, QList<QKeySequence>(), false, Category::View},
@@ -328,13 +335,14 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {Spelling, "Spelling", QT_TRANSLATE_NOOP3("KStandardShortcut", "Spelling", "@action"), 0, 0, QList<QKeySequence>(), false, Category::Edit},
     {ShowToolbar, "ShowToolbar", QT_TRANSLATE_NOOP3("KStandardShortcut", "Show Toolbar", "@action"), 0, 0, QList<QKeySequence>(), false, Category::View},
     {ShowStatusbar, "ShowStatusbar", QT_TRANSLATE_NOOP3("KStandardShortcut", "Show Statusbar", "@action"), 0, 0, QList<QKeySequence>(), false, Category::View},
-#if KCONFIGGUI_BUILD_DEPRECATED_SINCE(5, 39)
-    {SaveOptions, "SaveOptions", QT_TRANSLATE_NOOP3("KStandardShortcut", "Save Options", "@action"), 0, 0, QList<QKeySequence>(), false, Category::Settings},
-#else
-    // dummy entry
-    {SaveOptions_DEPRECATED_DO_NOT_USE, nullptr, {nullptr, nullptr}, 0, 0, QList<QKeySequence>(), false, Category::InvalidCategory},
-#endif
-    {KeyBindings, "KeyBindings", QT_TRANSLATE_NOOP3("KStandardShortcut", "Key Bindings", "@action"), CTRLALT(Comma), 0, QList<QKeySequence>(), false, Category::Settings},
+    {KeyBindings,
+     "KeyBindings",
+     QT_TRANSLATE_NOOP3("KStandardShortcut", "Key Bindings", "@action"),
+     CTRLALT(Comma),
+     0,
+     QList<QKeySequence>(),
+     false,
+     Category::Settings},
     {Preferences,
      "Preferences",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Configure Application", "@action"),
@@ -359,7 +367,6 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
      QList<QKeySequence>(),
      false,
      Category::Settings},
-    {TipofDay, "TipofDay", QT_TRANSLATE_NOOP3("KStandardShortcut", "Tip Of Day", "@action"), 0, 0, QList<QKeySequence>(), false, Category::Help},
     {ReportBug, "ReportBug", QT_TRANSLATE_NOOP3("KStandardShortcut", "Report Bug", "@action"), 0, 0, QList<QKeySequence>(), false, Category::Help},
     {SwitchApplicationLanguage,
      "SwitchApplicationLanguage",
@@ -395,11 +402,27 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {CreateFolder,
      "CreateFolder",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Create Folder", "@action"),
-     Qt::Key_F10,
+     CTRLSHIFT(N),
      0,
      QList<QKeySequence>(),
      false,
      Category::File},
+    {OpenMainMenu,
+     "OpenMainMenu",
+     QT_TRANSLATE_NOOP3("KStandardShortcut", "Open Main Menu", "@action referring to the menu bar or a hamburger menu"),
+     Qt::Key_F10,
+     0,
+     QList<QKeySequence>(),
+     false,
+     Category::View},
+    {OpenContextMenu,
+     "OpenContextMenu",
+     QT_TRANSLATE_NOOP3("KStandardShortcut", "Open Context Menu", "@action"),
+     Qt::Key_Menu,
+     SHIFT(F10),
+     QList<QKeySequence>(),
+     false,
+     Category::View},
 
     // dummy entry to catch simple off-by-one errors. Insert new entries before this line.
     {AccelNone, nullptr, {nullptr, nullptr}, 0, 0, QList<QKeySequence>(), false, Category::InvalidCategory}};
@@ -450,7 +473,7 @@ void initialize(StandardShortcut id)
         Q_ASSERT(info->name);
     }
 
-    KConfigGroup cg(KSharedConfig::openConfig(), "Shortcuts");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("Shortcuts"));
 
     if (cg.hasKey(info->name)) {
         QString s = cg.readEntry(info->name);
@@ -476,7 +499,7 @@ void saveShortcut(StandardShortcut id, const QList<QKeySequence> &newShortcut)
         return;
     }
 
-    KConfigGroup cg(KSharedConfig::openConfig(), "Shortcuts");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("Shortcuts"));
 
     info->cut = newShortcut;
     bool sameAsDefault = (newShortcut == hardcodedDefaultShortcut(id));
@@ -535,11 +558,7 @@ StandardShortcut find(const QKeySequence &seq)
     if (!seq.isEmpty()) {
         for (const KStandardShortcutInfo &shortcutInfo : g_infoStandardShortcut) {
             const StandardShortcut id = shortcutInfo.id;
-#if KCONFIGGUI_BUILD_DEPRECATED_SINCE(5, 39)
             if (id != AccelNone) {
-#else
-            if (id != AccelNone && id != SaveOptions_DEPRECATED_DO_NOT_USE) {
-#endif
                 if (!shortcutInfo.isInitialized) {
                     initialize(id);
                 }
@@ -552,23 +571,10 @@ StandardShortcut find(const QKeySequence &seq)
     return AccelNone;
 }
 
-#if KCONFIGGUI_BUILD_DEPRECATED_SINCE(5, 71)
-StandardShortcut find(const char *keyName)
-{
-    for (const KStandardShortcutInfo &shortcutInfo : g_infoStandardShortcut) {
-        if (qstrcmp(shortcutInfo.name, keyName) == 0) {
-            return shortcutInfo.id;
-        }
-    }
-
-    return AccelNone;
-}
-#endif
-
 StandardShortcut findByName(const QString &name)
 {
     for (const KStandardShortcutInfo &shortcutInfo : g_infoStandardShortcut) {
-        if (QString::fromLatin1(shortcutInfo.name) == name) {
+        if (QLatin1StringView(shortcutInfo.name) == name) {
             return shortcutInfo.id;
         }
     }
@@ -812,10 +818,16 @@ const QList<QKeySequence> &preferences()
 {
     return shortcut(Preferences);
 }
-
 const QList<QKeySequence> &showHideHiddenFiles()
 {
     return shortcut(ShowHideHiddenFiles);
 }
-
+const QList<QKeySequence> &openMainMenu()
+{
+    return shortcut(OpenMainMenu);
+}
+const QList<QKeySequence> &openContextMenu()
+{
+    return shortcut(OpenContextMenu);
+}
 }
